@@ -45,25 +45,28 @@ class SACTorchPolicy(TorchPolicy):
             self.module.alpha, self.module.actor.sample, target_entropy
         )
 
-    @staticmethod
+    @property
     @override(TorchPolicy)
-    def get_default_config():
-        """Return the default config for SAC."""
-        # pylint:disable=cyclic-import,protected-access
+    def options(self):
+        # pylint:disable=cyclic-import
         from raylab.agents.sac import SACTrainer
 
-        return SACTrainer._default_config
+        return SACTrainer.options
 
     @override(TorchPolicy)
-    def make_optimizers(self):
+    def _make_optimizers(self):
+        optimizers = super()._make_optimizers()
         config = self.config["torch_optimizer"]
-        components = "actor critics alpha".split()
 
-        return {
+        components = "actor critics alpha".split()
+        mapping = {
             name: build_optimizer(getattr(self.module, name), config[name])
             for name in components
         }
 
+        optimizers.update(mapping)
+        return optimizers
+
     @override(TorchPolicy)
     def learn_on_batch(self, samples):
         batch_tensors = self.lazy_tensor_dict(samples)
